==> hardhat_1.1.3.tar.xz: hardhat-1.1.3/src/maker.h <==
/******************************************************************************

	hardhat - read and write databases optimized for filename-like keys
	Copyright (c) 2011,2012 Wessel Dankers <wsl@fruit.je>

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program. If not, see <http://www.gnu.org/licenses/>.

******************************************************************************/

#ifndef HARDHAT_MAKER_H
#define HARDHAT_MAKER_H

#include <stdbool.h>
#include <stdint.h>
#include <stdlib.h>

typedef struct hardhat_maker hardhat_maker_t;

/* Retrieve the last error that occurred in the context of
   this hardhat_maker_t structure.
   Always returns a valid string, though it may be empty
   if there's no error to report.
   Do not attempt to free() the string. */
extern const char *hardhat_maker_error(hardhat_maker_t *hhm);

/* Returns true iff the creation of the database failed in a
   way that can't be recovered from */
extern bool hardhat_maker_fatal(hardhat_maker_t *hhm);

/* Allocate and initialize a new hardhat_maker_t control structure.
   Returns NULL (and sets errno) on error. */
extern hardhat_maker_t *hardhat_maker_new(const char *filename);

/* Add an entry. Will silently ignore attempts to add duplicate keys
   (and even return true). Returns false on error. */
extern bool hardhat_maker_add(hardhat_maker_t *hhm, const void *key, uint16_t keylen, const void *data, uint32_t datalen);

/* Fills in missing parent nodes. For example, if you add the following keys:

	foo
	foo/bar/baz

   Then doing a shallow listing on ‘foo’ would turn up 0 results. This
   function would add ‘foo/bar’ (with the indicated data) so that shallow
   listings function properly. This function will not add a root node (the
   empty string). Returns false on error. */
extern bool hardhat_maker_parents(hardhat_maker_t *hhm, const void *data, uint32_t datalen);

/* Create the indexes, write and flush everything to disk. Returns false on
   error. After calling this function, no entries can be added. */
extern bool hardhat_maker_finish(hardhat_maker_t *hhm);

/* Free the hardhat_maker_t control structure and any associated data. */
extern void hardhat_maker_free(hardhat_maker_t *hhm);

/* Utility function: normalize a path according to hardhat's rules.
   Returns the size of the result string. The destination buffer should
   be at least as large as the source buffer. In place conversions are
   supported (simply pass the same pointer for src and dst. */
extern size_t hardhat_normalize(uint8_t *dst, const uint8_t *src, size_t size);

/* Utility function: compare two paths according to hardhat's rules. */
extern int hardhat_cmp(const void *a, size_t al, const void *b, size_t bl);

#endif

==> hardhat_1.1.5.tar.xz: hardhat-1.1.5/src/maker.h <==
/******************************************************************************

	hardhat - read and write databases optimized for filename-like keys
	Copyright (c) 2011,2012 Wessel Dankers <wsl@fruit.je>

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program. If not, see <http://www.gnu.org/licenses/>.

******************************************************************************/

#ifndef HARDHAT_MAKER_H
#define HARDHAT_MAKER_H

#include <stdbool.h>
#include <stdint.h>
#include <stdlib.h>

typedef struct hardhat_maker hardhat_maker_t;

/* Retrieve the last error that occurred in the context of
   this hardhat_maker_t structure.
   Always returns a valid string, though it may be empty
   if there's no error to report.
   Do not attempt to free() the string. */
extern const char *hardhat_maker_error(hardhat_maker_t *hhm);

/* Returns true iff the creation of the database failed in a
   way that can't be recovered from */
extern bool hardhat_maker_fatal(hardhat_maker_t *hhm);

/* Allocate and initialize a new hardhat_maker_t control structure.
   Returns NULL (and sets errno) on error. */
extern hardhat_maker_t *hardhat_maker_new(const char *filename);

/* Add an entry. Will silently ignore attempts to add duplicate keys
   (and even return true). Returns false on error. */
extern bool hardhat_maker_add(hardhat_maker_t *hhm, const void *key, uint16_t keylen, const void *data, uint32_t datalen);

/* Fills in missing parent nodes. For example, if you add the following keys:

	foo
	foo/bar/baz

   Then doing a shallow listing on ‘foo’ would turn up 0 results. This
   function would add ‘foo/bar’ (with the indicated data) so that shallow
   listings function properly. This function will not add a root node (the
   empty string). Returns false on error. */
extern bool hardhat_maker_parents(hardhat_maker_t *hhm, const void *data, uint32_t datalen);

/* Create the indexes, write and flush everything to disk. Returns false on
   error. After calling this function, no entries can be added. */
extern bool hardhat_maker_finish(hardhat_maker_t *hhm);

/* Free the hardhat_maker_t control structure and any associated data. */
extern void hardhat_maker_free(hardhat_maker_t *hhm);

/* Utility function: normalize a path according to hardhat's rules.
   Returns the size of the result string. The destination buffer should
   be at least as large as the source buffer. In place conversions are
   supported (simply pass the same pointer for src and dst. */
extern size_t hardhat_normalize(void *dst, const void *src, size_t size);

/* Utility function: compare two paths according to hardhat's rules. */
extern int hardhat_cmp(const void *a, size_t al, const void *b, size_t bl);

#endif
